@@ -588,10 +588,21 @@ class AiServiceInstallApp(BaseApp, aiServiceInstallArgBuilderMixin, aiServiceIns
             "",
             "The project ID refers to your specific watsonx.ai project where your ML models and assets are stored.",
             "",
+            "Optional identifiers:",
+            " - DeploymentId: ID of the model deployment in a **dedicated watsonx runtime**",
+            "   (e.g., granite-3-2-8b-instruct deployed in your dedicated runtime).",
+            " - SpaceId: ID of the **watsonx deployment space** where deployments are managed.",
+            "Provide these only if you already have them; otherwise AI Service can proceed with defaults/workflows",
+            "that do not require pre-existing deployment/space identifiers.",
+            "",
         ])
         self.promptForString("Watsonxai api key", "aiservice_watsonxai_apikey", isPassword=True)
         self.promptForString("Watsonxai machine learning url", "aiservice_watsonxai_url")
         self.promptForString("Watsonxai project id", "aiservice_watsonxai_project_id")
+        if self.yesOrNo("Does the Watsonxai AI use a self-signed certificate?"):
+            self.promptForString("Watsonxai CA certificate (PEM format)", "aiservice_watsonxai_ca_crt")
+        self.promptForString("Watsonxai Deployment ID (optional)", "aiservice_watsonxai_deployment_id")
+        self.promptForString("Watsonxai Space ID (optional)", "aiservice_watsonxai_space_id")
 
         self.printH1("RSL Integration")
         self.printDescription([
