@@ -9,21 +9,20 @@
 # *****************************************************************************
 supportedCatalogs = {
     "amd64": [
+        "v9-251010-amd64",
+        "v9-250925-amd64",
         "v9-250902-amd64",
         "v9-250828-amd64",
-        "v9-250731-amd64",
-        "v9-250624-amd64",
     ],
     "s390x": [
+        # No "v9-250925-s390x" catalog for the s390x
         "v9-250902-s390x",
         "v9-250828-s390x",
-        "v9-250731-s390x",
-        "v9-250624-s390x",
     ],
     "ppc64le": [
+        "v9-251010-ppc64le",
+        "v9-250925-ppc64le",
         "v9-250902-ppc64le",
         "v9-250828-ppc64le",
-        "v9-250731-ppc64le",
-        "v9-250624-ppc64le",
     ],
 }
