@@ -53,8 +53,6 @@ optionalParams = [
     "mas_app_settings_old_crypto_key",
     "mas_app_settings_old_cryptox_key",
     "mas_app_settings_override_encryption_secrets_flag",
-    "mas_app_settings_base_lang",
-    "mas_app_settings_secondary_langs",
     "mas_app_settings_server_timezone",
     "mas_appws_bindings_jdbc_manage",
     "mas_appws_components",
@@ -66,13 +64,20 @@ optionalParams = [
     # SLS
     "sls_namespace",
     # DNS Providers
-    # TODO: Add CloudFlare and Route53 support
+    # TODO: Route53 support
     "dns_provider",
+    "mas_cluster_issuer",
+    "ocp_ingress",
+    # CIS
     "cis_email",
     "cis_apikey",
     "cis_crn",
     "cis_subdomain",
-    "mas_cluster_issuer",
+    # CloudFlare
+    "cloudflare_email",
+    "cloudflare_apitoken",
+    "cloudflare_zone",
+    "cloudflare_subdomain",
     # DRO
     "dro_namespace",
     # Db2
