@@ -254,13 +254,13 @@ class UpdateApp(BaseApp):
         self.printH1("Select IBM Maximo Operator Catalog Version")
         self.printDescription([
             "Select MAS Catalog",
-            "  1) Sep 02 2025 Update (MAS 9.1.2, 9.0.14, 8.11.23, &amp; 8.10.28)",
-            "  2) July 31 2025 Update (MAS 9.1.1, 9.0.13, 8.11.22, &amp; 8.10.27)",
-            "  3) Jun 24 2025 Update (MAS 9.1.0, 9.0.12, 8.11.21, &amp; 8.10.26)",
+            "  1) Oct 10 2025 Update (MAS 9.1.4, 9.0.15, 8.11.24, &amp; 8.10.29)",
+            "  2) Sep 25 2025 Update (MAS 9.1.4, 9.0.15, 8.11.24, &amp; 8.10.29)",
+            "  3) Sep 02 2025 Update (MAS 9.1.2, 9.0.14, 8.11.23, &amp; 8.10.28)",
         ])
 
         catalogOptions = [
-            "v9-250902-amd64", "v9-250731-amd64", "v9-250624-amd64",
+            "v9-251010-amd64", "v9-250925-amd64", "v9-250902-amd64",
         ]
         self.promptForListSelect("Select catalog version", catalogOptions, "mas_catalog_version", default=1)
 
@@ -379,6 +379,8 @@ class UpdateApp(BaseApp):
                         "v9-250731-amd64": "7.0.22",
                         "v9-250828-amd64": "7.0.22",
                         "v9-250902-amd64": "7.0.22",
+                        "v9-250925-amd64": "7.0.23",
+                        "v9-251010-amd64": "7.0.23",
                     }
                     catalogVersion = self.getParam('mas_catalog_version')
                     if catalogVersion in mongoVersions:
@@ -518,6 +520,8 @@ class UpdateApp(BaseApp):
             "v9-250731-amd64": "5.1.3",
             "v9-250828-amd64": "5.1.3",
             "v9-250902-amd64": "5.1.3",
+            "v9-250925-amd64": "5.1.3",
+            "v9-251010-amd64": "5.1.3",
         }
 
         with Halo(text='Checking for IBM Cloud Pak for Data', spinner=self.spinner) as h:
